==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/FeatureGatesEnabledBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FeatureGatesEnabledBuilder extends FeatureGatesEnabledFluentImpl<FeatureGatesEnabledBuilder> implements VisitableBuilder<FeatureGatesEnabled,FeatureGatesEnabledBuilder>{
  public FeatureGatesEnabledBuilder() {
    this(false);
  }
  public FeatureGatesEnabledBuilder(Boolean validationEnabled) {
    this(new FeatureGatesEnabled(), validationEnabled);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent) {
    this(fluent, false);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FeatureGatesEnabled(), validationEnabled);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent,FeatureGatesEnabled instance) {
    this(fluent, instance, false);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent,FeatureGatesEnabled instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withEnabled(instance.getEnabled());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabled instance) {
    this(instance,false);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabled instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  FeatureGatesEnabledFluent<?> fluent;
  Boolean validationEnabled;
  public FeatureGatesEnabled build() {
    FeatureGatesEnabled buildable = new FeatureGatesEnabled(fluent.getEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/FeatureGatesEnabledBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FeatureGatesEnabledBuilder extends FeatureGatesEnabledFluent<FeatureGatesEnabledBuilder> implements VisitableBuilder<FeatureGatesEnabled,FeatureGatesEnabledBuilder>{
  public FeatureGatesEnabledBuilder() {
    this(false);
  }
  public FeatureGatesEnabledBuilder(Boolean validationEnabled) {
    this(new FeatureGatesEnabled(), validationEnabled);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent) {
    this(fluent, false);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FeatureGatesEnabled(), validationEnabled);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent,FeatureGatesEnabled instance) {
    this(fluent, instance, false);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabledFluent<?> fluent,FeatureGatesEnabled instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new FeatureGatesEnabled());

    if (instance != null) {
      fluent.withEnabled(instance.getEnabled());
      fluent.withEnabled(instance.getEnabled());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabled instance) {
    this(instance,false);
  }
  public FeatureGatesEnabledBuilder(FeatureGatesEnabled instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new FeatureGatesEnabled());

    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  FeatureGatesEnabledFluent<?> fluent;
  Boolean validationEnabled;
  public FeatureGatesEnabled build() {
    FeatureGatesEnabled buildable = new FeatureGatesEnabled(fluent.getEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
